@@ -150,7 +150,7 @@ class CRFExtractor:
 
 
     @check_model_loaded
-    def tag(self, mlp_document: dict, field_name: str = "text_mlp"):
+    def tag(self, mlp_document: dict, field_name: str = "text_mlp", label_suffix: str = ""):
         """
         Tags input MLP document.
         """
@@ -167,7 +167,7 @@ class CRFExtractor:
             features_to_predict = self.feature_extractor.sent2features(seq_to_predict)
             result = self.model.tag(features_to_predict)
             # generate text tokens for final output
-            for tag in self._process_tag_output(result, sentences, i, field_name):
+            for tag in self._process_tag_output(result, sentences, i, field_name, label_suffix):
                 facts.append(tag)
         out_doc = {
             field_name: {
@@ -198,7 +198,7 @@ class CRFExtractor:
         }
 
 
-    def _process_tag_output(self, tokens: List[str], sentences: List[List[str]], sent_index: int, field_name: str):
+    def _process_tag_output(self, tokens: List[str], sentences: List[List[str]], sent_index: int, field_name: str, label_suffix: str = ""):
         """
         Translates result tokens into entities.
         """
@@ -224,7 +224,7 @@ class CRFExtractor:
             pattern = re.compile(re.escape(str_val))
             matching_spans = [(match.start(), match.end()) for match in pattern.finditer(tokenized_sentence)]
             fact = {
-                "fact": fact_name,
+                "fact": fact_name if not label_suffix else f"{fact_name}_{label_suffix}", # if the user has specified a suffix, append it to the fact name
                 "str_val": str_val,
                 "sent_index": sent_index,
                 "doc_path": f"{field_name}.{FEATURE_LAYER_WORD}",
