@@ -1,4 +1,6 @@
 from typing import List, Tuple
+from enum import Enum
+
 from . import exceptions
 
 # define token extractor names & defaults
@@ -19,6 +21,10 @@ DEFAULT_LAYERS = [FEATURE_LAYER_WORD, FEATURE_LAYER_LEMMA, FEATURE_LAYER_POS, FE
 KNOWN_LAYERS = [FEATURE_LAYER_WORD, FEATURE_LAYER_LEMMA, FEATURE_LAYER_POS, FEATURE_LAYER_GRAMMAR]
 
 
+class FeatureType(Enum):
+    MAIN = "main"
+    CONTEXT = "context"
+
 
 class FeatureExtractor:
 
@@ -46,13 +52,20 @@ class FeatureExtractor:
         return False
 
 
-    def _extract_features(self, item: dict, word_index: int, extractors_to_use: list):
+    def _extract_features(self, item: dict, word_index: int, extractors_to_use: list, feature_type: FeatureType):
         """
         Extract features from token and surrounding tokens based on window size.
         """
         features = []
+        
         # select features from selected layers
-        layers_to_use = self.config.feature_layers+self.config.context_feature_layers
+        if feature_type == FeatureType.MAIN:
+            layers_to_use = self.config.feature_layers
+
+        elif feature_type == FeatureType.CONTEXT:
+            layers_to_use = self.config.context_feature_layers
+
+        #layers_to_use = self.config.feature_layers+self.config.context_feature_layers
         for layer in layers_to_use:
             if layer not in item:
                 raise exceptions.InvalidInputError(f"Layer {layer} not present in document!")
@@ -72,9 +85,8 @@ class FeatureExtractor:
             if layer == FEATURE_LAYER_WORD:
                 for i in range(self.config.suffix_len[0], self.config.suffix_len[1]+1):
                     features.append(f"{word_index}:{layer}.suffix={value[-i:]}")
-
+        # extract more features from token
         if FEATURE_LAYER_WORD in item:
-            # extract more features from token
             token = item[FEATURE_LAYER_WORD]
             for extractor in extractors_to_use:
                 if extractor == EXTRACTOR_ISUPPER:
@@ -90,12 +102,11 @@ class FeatureExtractor:
 
         # get similar lemmas from embedding
         if self.embedding and FEATURE_LAYER_LEMMA in item:
-            most_similar_lemmas = self.embedding.get_similar([item[FEATURE_LAYER_LEMMA]], n=1)
+            most_similar_lemmas = self.embedding.get_similar([item[FEATURE_LAYER_LEMMA]], n=self.config.embedding_n_similar)
             if len(most_similar_lemmas):
-                most_similar_lemma = most_similar_lemmas[0]["phrase"]
-                features.append(f"{word_index}:{FEATURE_LAYER_LEMMA}.embedding={most_similar_lemma}")
-            else:
-                features.append(f"{word_index}:{FEATURE_LAYER_LEMMA}.embedding=NA")
+                for most_similar_lemma in most_similar_lemmas:
+                    most_similar_lemma = most_similar_lemma["phrase"]
+                    features.append(f"{word_index}:{FEATURE_LAYER_LEMMA}.embedding={most_similar_lemma}")
         # replace newlines as it breaks taggerinfo()
         features = [f.replace("\n", "") for f in features]
         return features
@@ -115,7 +126,7 @@ class FeatureExtractor:
         item = {}
         for layer_name in self.config.feature_layers:
             item[layer_name] = sent[i][0][layer_name]
-        features.extend(self._extract_features(item, "0", self.config.feature_extractors))
+        features.extend(self._extract_features(item, "0", self.config.feature_extractors, FeatureType.MAIN))
         # check if not the first token in sentence
         if i > 0:
             for window in range(1, self.config.window_size+1):
@@ -123,7 +134,7 @@ class FeatureExtractor:
                     item1 = {}
                     for layer_name in self.config.context_feature_layers:
                         item1[layer_name] = sent[i-window][0][layer_name]
-                    features.extend(self._extract_features(item1, f"-{window}", self.config.context_feature_extractors))
+                    features.extend(self._extract_features(item1, f"-{window}", self.config.context_feature_extractors, FeatureType.CONTEXT))
                 except IndexError:
                     pass
         else:
@@ -136,7 +147,7 @@ class FeatureExtractor:
                     item1 = {}
                     for layer_name in self.config.context_feature_layers:
                         item1[layer_name] = sent[i+window][0][layer_name]
-                    features.extend(self._extract_features(item1, f"+{window}", self.config.context_feature_extractors))
+                    features.extend(self._extract_features(item1, f"+{window}", self.config.context_feature_extractors, FeatureType.CONTEXT))
                 except IndexError:
                     pass
         else:
@@ -193,4 +204,4 @@ class FeatureExtractor:
             for sentence in sentences:
                 sentence_tokens = sentence.split(" ")
                 layers[field].append(sentence_tokens)
-        return layers
\ No newline at end of file
+        return layers
